@@ -6,47 +6,64 @@
 #'   `print(..., simplify=FALSE)` to print a more detailed summary.
 #'
 #' @export
-#' @param x An object of class `"loo"` or a list of such objects.
-#' @param ... Additional objects of class `"loo"`.
+#' @param x An object of class `"loo"` or a list of such objects. If a list is
+#'   used then the list names will be used as the model names in the output. See
+#'   **Examples**.
+#' @param ... Additional objects of class `"loo"`, if not passed in as a single
+#'   list.
 #'
 #' @return A matrix with class `"compare.loo"` that has its own
 #'   print method. See the **Details** section.
 #'
 #' @details
 #'   When comparing two fitted models, we can estimate the difference in their
-#'   expected predictive accuracy by the difference in `elpd_loo` or
-#'   `elpd_waic` (or multiplied by \eqn{-2}, if desired, to be on the
-#'   deviance scale).
+#'   expected predictive accuracy by the difference in
+#'   [`elpd_loo`][loo-glossary] or `elpd_waic` (or multiplied by \eqn{-2}, if
+#'   desired, to be on the deviance scale).
 #'
-#'   When using `loo_compare()`, the returned matrix will have one row per
-#'   model and several columns of estimates. The values in the `elpd_diff`
-#'   and `se_diff` columns of the returned matrix are computed by making
-#'   pairwise comparisons between each model and the model with the largest ELPD
-#'   (the model in the first row). For this reason the `elpd_diff` column
-#'   will always have the value `0` in the first row (i.e., the difference
-#'   between the preferred model and itself) and negative values in subsequent
-#'   rows for the remaining models.
+#'   When using `loo_compare()`, the returned matrix will have one row per model
+#'   and several columns of estimates. The values in the
+#'   [`elpd_diff`][loo-glossary] and [`se_diff`][loo-glossary] columns of the
+#'   returned matrix are computed by making pairwise comparisons between each
+#'   model and the model with the largest ELPD (the model in the first row). For
+#'   this reason the `elpd_diff` column will always have the value `0` in the
+#'   first row (i.e., the difference between the preferred model and itself) and
+#'   negative values in subsequent rows for the remaining models.
 #'
-#'   To compute the standard error of the difference in ELPD --- which should
-#'   not be expected to equal the difference of the standard errors --- we use a
-#'   paired estimate to take advantage of the fact that the same set of \eqn{N}
-#'   data points was used to fit both models. These calculations should be most
-#'   useful when \eqn{N} is large, because then non-normality of the
-#'   distribution is not such an issue when estimating the uncertainty in these
-#'   sums. These standard errors, for all their flaws, should give a better
-#'   sense of uncertainty than what is obtained using the current standard
-#'   approach of comparing differences of deviances to a Chi-squared
+#'   To compute the standard error of the difference in [ELPD][loo-glossary] ---
+#'   which should not be expected to equal the difference of the standard errors
+#'   --- we use a paired estimate to take advantage of the fact that the same
+#'   set of \eqn{N} data points was used to fit both models. These calculations
+#'   should be most useful when \eqn{N} is large, because then non-normality of
+#'   the distribution is not such an issue when estimating the uncertainty in
+#'   these sums. These standard errors, for all their flaws, should give a
+#'   better sense of uncertainty than what is obtained using the current
+#'   standard approach of comparing differences of deviances to a Chi-squared
 #'   distribution, a practice derived for Gaussian linear models or
 #'   asymptotically, and which only applies to nested models in any case.
+#'   Sivula et al. (2022) discuss the conditions when the normal
+#'   approximation used for SE and `se_diff` is good.
 #'
-#' @template loo-and-psis-references
+#'   If more than \eqn{11} models are compared, we internally recompute the model
+#'   differences using the median model by ELPD as the baseline model. We then
+#'   estimate whether the differences in predictive performance are potentially
+#'   due to chance as described by McLatchie and Vehtari (2023). This will flag
+#'   a warning if it is deemed that there is a risk of over-fitting due to the
+#'   selection process. In that case users are recommended to avoid model
+#'   selection based on LOO-CV, and instead to favor model averaging/stacking or
+#'   projection predictive inference.
+#' 
+#' @seealso
+#' * The [FAQ page](https://mc-stan.org/loo/articles/online-only/faq.html) on
+#'   the __loo__ website for answers to frequently asked questions.
+#' @template loo-and-compare-references
 #'
 #' @examples
 #' # very artificial example, just for demonstration!
 #' LL <- example_loglik_array()
-#' loo1 <- loo(LL, r_eff = NA)     # should be worst model when compared
-#' loo2 <- loo(LL + 1, r_eff = NA) # should be second best model when compared
-#' loo3 <- loo(LL + 2, r_eff = NA) # should be best model when compared
+#' loo1 <- loo(LL)     # should be worst model when compared
+#' loo2 <- loo(LL + 1) # should be second best model when compared
+#' loo3 <- loo(LL + 2) # should be best model when compared
 #'
 #' comp <- loo_compare(loo1, loo2, loo3)
 #' print(comp, digits = 2)
@@ -55,8 +72,9 @@
 #' # (will be the same for all models in this artificial example)
 #' print(comp, simplify = FALSE, digits = 3)
 #'
-#' # can use a list of objects
-#' loo_compare(x = list(loo1, loo2, loo3))
+#' # can use a list of objects with custom names
+#' # will use apple, banana, and cherry, as the names in the output
+#' loo_compare(list("apple" = loo1, "banana" = loo2, "cherry" = loo3))
 #'
 #' \dontrun{
 #' # works for waic (and kfold) too
@@ -101,6 +119,9 @@ loo_compare.default <- function(x, ...) {
   comp <- cbind(elpd_diff = elpd_diff, se_diff = se_diff, comp)
   rownames(comp) <- rnms
 
+  # run order statistics-based checks on models
+  loo_order_stat_check(loos, ord)
+
   class(comp) <- c("compare.loo", class(comp))
   return(comp)
 }
@@ -165,9 +186,15 @@ loo_compare_checks <- function(loos) {
     stop("All inputs should have class 'loo'.", call.=FALSE)
   }
 
-  Ns <- sapply(loos, function(x) nrow(x$pointwise))
-  if (!all(Ns == Ns[1L])) {
-    stop("Not all models have the same number of data points.", call.=FALSE)
+  Ns <- vapply(loos, function(x) nrow(x$pointwise), integer(1))
+  if (any(Ns != Ns[1L])) {
+    stop(
+      paste0(
+        "All models must have the same number of observations, but models have inconsistent observation counts: ",
+        paste(paste0("'", find_model_names(loos), "' (", Ns, ")"), collapse = ", ")
+      ), 
+      call. = FALSE
+    )
   }
 
   ## warnings
@@ -224,8 +251,7 @@ find_model_names <- function(x) {
       out_names[j] <- names4[j]
     }
   }
-
-  return(out_names)
+  out_names
 }
 
 
@@ -264,3 +290,63 @@ loo_compare_order <- function(loos){
   ord <- order(tmp[grep("^elpd", rnms), ], decreasing = TRUE)
   ord
 }
+
+#' Perform checks on `"loo"` objects __after__ comparison
+#' @noRd
+#' @keywords internal
+#' @param loos List of `"loo"` objects.
+#' @param ord List of `"loo"` object orderings.
+#' @return Nothing, just possibly throws errors/warnings.
+loo_order_stat_check <- function(loos, ord) {
+
+  ## breaks
+
+  if (length(loos) <= 11L) {
+    # procedure cannot be diagnosed for fewer than ten candidate models
+    # (total models = worst model + ten candidates)
+    # break from function
+    return(NULL)
+  }
+
+  ## warnings
+
+  # compute the elpd differences from the median model
+  baseline_idx <- middle_idx(ord)
+  diffs <- mapply(FUN = elpd_diffs, loos[ord[baseline_idx]], loos[ord])
+  elpd_diff <- apply(diffs, 2, sum)
+
+  # estimate the standard deviation of the upper-half-normal
+  diff_median <- stats::median(elpd_diff)
+  elpd_diff_trunc <- elpd_diff[elpd_diff >= diff_median]
+  n_models <- sum(!is.na(elpd_diff_trunc))
+  candidate_sd <- sqrt(1 / n_models * sum(elpd_diff_trunc^2, na.rm = TRUE))
+
+  # estimate expected best diff under null hypothesis
+  K <- length(loos) - 1
+  order_stat <- order_stat_heuristic(K, candidate_sd)
+
+  if (max(elpd_diff) <= order_stat) {
+    # flag warning if we suspect no model is theoretically better than the baseline
+    warning("Difference in performance potentially due to chance.",
+            "See McLatchie and Vehtari (2023) for details.",
+            call. = FALSE)
+  }
+}
+
+#' Returns the middle index of a vector
+#' @noRd
+#' @keywords internal
+#' @param vec A vector.
+#' @return Integer index value.
+middle_idx <- function(vec) floor(length(vec) / 2)
+
+#' Computes maximum order statistic from K Gaussians
+#' @noRd
+#' @keywords internal
+#' @param K Number of Gaussians.
+#' @param c Scaling of the order statistic.
+#' @return Numeric expected maximum from K samples from a Gaussian with mean
+#' zero and scale `"c"`
+order_stat_heuristic <- function(K, c) {
+  qnorm(p = 1 - 1 / (K * 2), mean = 0, sd = c)
+}
