@@ -24,11 +24,11 @@ test_that("crps computation is correct", {
   expect_equal(.crps_fun(pi, pi^2, scale = TRUE), -pi^2/pi - 0.5 * log(pi))
 })
 
-test_that("crps matches references", {
-  expect_equal_to_reference(with_seed(1, crps(x1, x2, y)), 'reference-results/crps.rds')
-  expect_equal_to_reference(with_seed(1, scrps(x1, x2, y)), 'reference-results/scrps.rds')
-  expect_equal_to_reference(with_seed(1, loo_crps(x1, x2, y, ll)), 'reference-results/loo_crps.rds')
-  expect_equal_to_reference(with_seed(1, loo_scrps(x1, x2, y, ll)), 'reference-results/loo_scrps.rds')
+test_that("crps matches snapshots", {
+  expect_snapshot_value(with_seed(1, crps(x1, x2, y)), style = "serialize")
+  expect_snapshot_value(with_seed(1, scrps(x1, x2, y)), style = "serialize")
+  expect_snapshot_value(with_seed(1, loo_crps(x1, x2, y, ll)), style = "serialize")
+  expect_snapshot_value(with_seed(1, loo_scrps(x1, x2, y, ll)), style = "serialize")
 })
 
 test_that("input validation throws correct errors", {
