@@ -1,6 +1,3 @@
-library(loo)
-
-context("extract_log_lik")
 test_that("extract_log_lik throws appropriate errors", {
   x1 <- rnorm(100)
   expect_error(extract_log_lik(x1), regexp = "Not a stanfit object")
